==> jc-1.4.0.tar.gz: soot/jimple/internal/StmtBox.h <==
// public class soot.jimple.internal.StmtBox

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5cec03cf39985907 soot_AbstractUnitBox
// @dep_class b1d84de4e2c7e95 soot_jimple_internal_StmtBox

// header file dependencies
// @dep_header soot_AbstractUnitBox

#include "soot/AbstractUnitBox.h"

#ifndef _JC_soot_jimple_internal_StmtBox_H_
#define _JC_soot_jimple_internal_StmtBox_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Unit$object;
struct _jc_soot_jimple_Stmt$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_StmtBox$sub_refs	_jc_soot_jimple_internal_StmtBox$sub_refs;
typedef struct _jc_soot_jimple_internal_StmtBox$sub_nonrefs	_jc_soot_jimple_internal_StmtBox$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_StmtBox$refs	_jc_soot_jimple_internal_StmtBox$refs;
typedef struct _jc_soot_jimple_internal_StmtBox$nonrefs	_jc_soot_jimple_internal_StmtBox$nonrefs;
typedef struct _jc_soot_jimple_internal_StmtBox$object	_jc_soot_jimple_internal_StmtBox$object;

typedef const struct _jc_soot_jimple_internal_StmtBox$vmethods	_jc_soot_jimple_internal_StmtBox$vmethods;
typedef const struct _jc_soot_jimple_internal_StmtBox$vtable	_jc_soot_jimple_internal_StmtBox$vtable;
typedef const struct _jc_soot_jimple_internal_StmtBox$vtype	_jc_soot_jimple_internal_StmtBox$vtype;

// Constructors
extern void _jc_soot_jimple_internal_StmtBox$method$_init$3c88635eae989746(_jc_env *, struct _jc_soot_jimple_internal_StmtBox$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_soot_jimple_internal_StmtBox$method$canContainUnit$081e9f3eeb61f46c(_jc_env *, struct _jc_soot_jimple_internal_StmtBox$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_StmtBox$method_info$canContainUnit$081e9f3eeb61f46c;

// Virtual methods structure
struct _jc_soot_jimple_internal_StmtBox$vmethods {
	jboolean	(*canContainUnit$081e9f3eeb61f46c)(_jc_env *, struct _jc_soot_jimple_internal_StmtBox$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_internal_StmtBox$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_AbstractUnitBox$vmethods	soot_AbstractUnitBox;
	_jc_soot_jimple_internal_StmtBox$vmethods	soot_jimple_internal_StmtBox;
};

// Vtype
struct _jc_soot_jimple_internal_StmtBox$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_StmtBox$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_StmtBox$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_StmtBox$refs {
    _jc_soot_jimple_internal_StmtBox$sub_refs	soot_jimple_internal_StmtBox;
    _jc_soot_AbstractUnitBox$sub_refs	soot_AbstractUnitBox;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_StmtBox$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_StmtBox$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_AbstractUnitBox$sub_nonrefs	soot_AbstractUnitBox;
    _jc_soot_jimple_internal_StmtBox$sub_nonrefs	soot_jimple_internal_StmtBox;
};

// Object instance structure
struct _jc_soot_jimple_internal_StmtBox$object {
	_jc_soot_jimple_internal_StmtBox$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_StmtBox$vtype	*vtype;
	_jc_soot_jimple_internal_StmtBox$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_StmtBox$vtype _jc_soot_jimple_internal_StmtBox$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_StmtBox, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_StmtBox$class_object;

#endif	/* _JC_soot_jimple_internal_StmtBox_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/StmtBox.h <==
// public class soot.jimple.internal.StmtBox

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5cec03cf39985907 soot_AbstractUnitBox
// @dep_class b1d84de4e2c7e95 soot_jimple_internal_StmtBox

// header file dependencies
// @dep_header soot_AbstractUnitBox

#include "soot/AbstractUnitBox.h"

#ifndef _JC_soot_jimple_internal_StmtBox_H_
#define _JC_soot_jimple_internal_StmtBox_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Unit$object;
struct _jc_soot_jimple_Stmt$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_StmtBox$sub_refs	_jc_soot_jimple_internal_StmtBox$sub_refs;
typedef struct _jc_soot_jimple_internal_StmtBox$sub_nonrefs	_jc_soot_jimple_internal_StmtBox$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_StmtBox$refs	_jc_soot_jimple_internal_StmtBox$refs;
typedef struct _jc_soot_jimple_internal_StmtBox$nonrefs	_jc_soot_jimple_internal_StmtBox$nonrefs;
typedef struct _jc_soot_jimple_internal_StmtBox$object	_jc_soot_jimple_internal_StmtBox$object;

typedef const struct _jc_soot_jimple_internal_StmtBox$vmethods	_jc_soot_jimple_internal_StmtBox$vmethods;
typedef const struct _jc_soot_jimple_internal_StmtBox$vtable	_jc_soot_jimple_internal_StmtBox$vtable;
typedef const struct _jc_soot_jimple_internal_StmtBox$vtype	_jc_soot_jimple_internal_StmtBox$vtype;

// Constructors
extern void _jc_soot_jimple_internal_StmtBox$method$_init$3c88635eae989746(_jc_env *, struct _jc_soot_jimple_internal_StmtBox$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_jimple_internal_StmtBox$method$canContainUnit$081e9f3eeb61f46c(_jc_env *, struct _jc_soot_jimple_internal_StmtBox$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_StmtBox$method_info$canContainUnit$081e9f3eeb61f46c;

// Virtual methods structure
struct _jc_soot_jimple_internal_StmtBox$vmethods {
	jboolean	(*canContainUnit$081e9f3eeb61f46c)(_jc_env *, struct _jc_soot_jimple_internal_StmtBox$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_internal_StmtBox$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_AbstractUnitBox$vmethods	soot_AbstractUnitBox;
	_jc_soot_jimple_internal_StmtBox$vmethods	soot_jimple_internal_StmtBox;
};

// Vtype
struct _jc_soot_jimple_internal_StmtBox$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_StmtBox$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_StmtBox$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_StmtBox$refs {
    _jc_soot_jimple_internal_StmtBox$sub_refs	soot_jimple_internal_StmtBox;
    _jc_soot_AbstractUnitBox$sub_refs	soot_AbstractUnitBox;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_StmtBox$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_StmtBox$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_AbstractUnitBox$sub_nonrefs	soot_AbstractUnitBox;
    _jc_soot_jimple_internal_StmtBox$sub_nonrefs	soot_jimple_internal_StmtBox;
};

// Object instance structure
struct _jc_soot_jimple_internal_StmtBox$object {
	_jc_soot_jimple_internal_StmtBox$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_StmtBox$vtype	*vtype;
	_jc_soot_jimple_internal_StmtBox$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_StmtBox$vtype _jc_soot_jimple_internal_StmtBox$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_StmtBox, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_StmtBox$class_object;

#endif	/* _JC_soot_jimple_internal_StmtBox_H_ */
